@@ -4,7 +4,7 @@ from typing import Optional
 
 
 class Altinn3CloudEvent(BaseModel):
-    alternativesubject: str
+    alternativesubject: Optional[str]
     data: Optional[str]
     datacontenttype: Optional[str]
     id: str
@@ -47,4 +47,9 @@ class Altinn3CloudEvent(BaseModel):
                 "Field 'subject' must have a value for all non-validation events."
             )
 
+        if not values.get("alternativesubject"):
+            raise ValueError(
+                "Field 'alternativesubject' must have a value for all non-validation events."
+            )
+
         return values
